pub struct TxFunction {
pub op: PlainSymbol,
}Expand description
A “transaction function” that exposes some value determined by the current transaction. The
prototypical example is the current transaction ID, (transaction-tx).
A natural next step might be to expose the current transaction instant (transaction-instant),
but that’s more difficult: the transaction itself can set the transaction instant (with some
restrictions), so the transaction function must be late-binding. Right now, that’s difficult to
arrange in the transactor.
In the future, we might accept arguments; for example, perhaps we might expose (ancestor (transaction-tx) n) to find the n-th ancestor of the current transaction. If we do accept
arguments, then the special case of (lookup-ref a v) should be handled as part of the
generalization.
Fields
op: PlainSymbolTrait Implementations
Sourceimpl Clone for TxFunction
impl Clone for TxFunction
Sourcefn clone(&self) -> TxFunction
fn clone(&self) -> TxFunction
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for TxFunction
impl Debug for TxFunction
impl Eq for TxFunction
Sourceimpl<V: TransactableValueMarker> From<TxFunction> for ValuePlace<V>
impl<V: TransactableValueMarker> From<TxFunction> for ValuePlace<V>
Sourcefn from(v: TxFunction) -> Self
fn from(v: TxFunction) -> Self
Sourceimpl<V: TransactableValueMarker> From<TxFunction> for EntityPlace<V>
impl<V: TransactableValueMarker> From<TxFunction> for EntityPlace<V>
Sourcefn from(v: TxFunction) -> Self
fn from(v: TxFunction) -> Self
Sourceimpl Hash for TxFunction
impl Hash for TxFunction
Sourceimpl Ord for TxFunction
impl Ord for TxFunction
Sourcefn cmp(&self, other: &TxFunction) -> Ordering
fn cmp(&self, other: &TxFunction) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Sourceimpl PartialEq for TxFunction
impl PartialEq for TxFunction
Sourcefn eq(&self, other: &TxFunction) -> bool
fn eq(&self, other: &TxFunction) -> bool
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for TxFunction
impl PartialOrd for TxFunction
impl StructuralPartialEq for TxFunction