pub enum PatternNonValuePlace {
Placeholder,
Variable(Variable),
Entid(i64),
Ident(ValueRc<Keyword>),
}Expand description
e, a, tx can’t be values – no strings, no floats – and so they can only be variables, entity IDs, ident keywords, or placeholders. This encoding allows us to represent integers that aren’t entity IDs. That’ll get filtered out in the context of the database.
Variants