ParsedQuery

Struct ParsedQuery 

pub struct ParsedQuery {
    pub find_spec: FindSpec,
    pub default_source: SrcVar,
    pub with: Vec<Variable>,
    pub in_bindings: Vec<Binding>,
    pub in_sources: BTreeSet<SrcVar>,
    pub limit: Limit,
    pub where_clauses: Vec<WhereClause>,
    pub order: Option<Vec<Order>>,
}

Fields

find_spec: FindSpecdefault_source: SrcVarwith: Vec<Variable>in_bindings: Vec<Binding>in_sources: BTreeSet<SrcVar>limit: Limitwhere_clauses: Vec<WhereClause>order: Option<Vec<Order>>

Implementations

Source

impl ParsedQuery

A ParsedQuery represents a parsed but potentially invalid query to the query algebrizer. Such a query is syntactically valid but might be semantically invalid, for example because constraints on the set of variables are not respected.

We split ParsedQuery from FindQuery because it’s not easy to generalize over containers (here, Vec and BTreeSet) in Rust.

pub fn in_vars(&self) -> Vec<Variable>

Extract a flat list of variables from in_bindings (each binding contributes its variable(s)).